@@ -4,6 +4,7 @@
 import calendar
 import logging
 import multiprocessing
+import time
 from datetime import datetime, timedelta
 
 import redis
@@ -52,6 +53,9 @@ class WakaQ:
         schedules=[],
         host="localhost",
         port=6379,
+        username=None,
+        password=None,
+        db=0,
         concurrency=0,
         exclude_queues=[],
         max_retries=None,
@@ -113,6 +117,9 @@ class WakaQ:
         self.broker = redis.Redis(
             host=host,
             port=port,
+            username=username,
+            password=password,
+            db=db,
             charset="utf-8",
             decode_responses=True,
             health_check_interval=health_check_interval,
@@ -211,6 +218,9 @@ class WakaQ:
         return self.broker.publish(self.broadcast_key, payload)
 
     def _blocking_dequeue(self):
+        if len(self.broker_keys) == 0:
+            time.sleep(self.wait_timeout)
+            return None, None
         data = self.broker.blpop(self.broker_keys, self.wait_timeout)
         if data is None:
             return None, None
