@@ -9,8 +9,8 @@ from .scheduler import Scheduler
 from .utils import (
     import_app,
     inspect,
-    pending_eta_tasks_in_queue,
-    pending_tasks_in_queue,
+    num_pending_eta_tasks_in_queue,
+    num_pending_tasks_in_queue,
     purge_eta_queue,
     purge_queue,
 )
@@ -50,8 +50,8 @@ def purge(**options):
     """Remove and empty all pending tasks in a queue."""
     wakaq = import_app(options.pop("app"))
     queue_name = options.pop("queue")
-    count = pending_tasks_in_queue(wakaq, queue_name=queue_name)
+    count = num_pending_tasks_in_queue(wakaq, queue_name=queue_name)
     purge_queue(wakaq, queue_name=queue_name)
-    count += pending_eta_tasks_in_queue(wakaq, queue_name=queue_name)
+    count += num_pending_eta_tasks_in_queue(wakaq, queue_name=queue_name)
     purge_eta_queue(wakaq, queue_name=queue_name)
     click.echo(f"Purged {count} tasks from {queue_name}")
